-- Multimodule protocols (MPM)

local FAILSAFE = 1
local TELEMETRY = 2

local RF_TUNE_OPTION = {name="Ladeni RF", min=-125, max=125, display=function(value) return value end }
local SERVO_REFRESH_RATE_OPTION = {name="Servo Refresh Rate", min=0, max=70, display=function(value) return (value * 5 + 50) .. "Hz" end }

local function init()
system.registerMultimoduleProtocol("Assan", 24, {options={RF_TUNE_OPTION}})	
system.registerMultimoduleProtocol("Bayang", 14, {variants={"Bayang", "H8S3D", "X16_AH", "IRDRONE", "DHD_D4", "QX100"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("Bayang RX", 59, {variants={"Multi", "CPPM"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("Bugs", 41, {options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("BugsMini", 42, {variants={"BUGSMINI", "BUGS3H"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("Cabell", 34, {variants={"Cabell_V3", "C_TELEM", "0", "0", "0", "0", "F_SAFE", "UNBIND"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("CFlie", 38, {variants={"CFlie"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("CG023", 13, {variants={"CG023", "YD829"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("Corona", 37, {variants={"COR_V1", "COR_V2", "FD_V3"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("CX10", 12, {variants={"GREEN", "BLUE", "DM007", "0", "J3015_1", "J3015_2", "MK33041"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("Devo", 7, {variants={"8CH", "10CH", "12CH", "6CH", "7CH"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("DM002", 33, {options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("DSM_RX", 70, {variants={"Multi", "CPPM"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("E010R5", 81, {options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("E016H", 85, {options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("E016HV2", 80, {options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("E01X", 45, {variants={"E012", "E015"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("E129", 83, {variants={"E129", "C186"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("ESky", 16, {variants={"ESky", "ET4"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("ESky150", 35, {options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("ESky150V2", 69, {options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("FlySky AFHDS 2A", 28, {variants={"PWM+IBUS", "PPM+IBUS", "PWM+SBUS", "PPM+SBUS", "PWM+IBUS16", "PPM+IBUS16"}, features=FAILSAFE+TELEMETRY, options={SERVO_REFRESH_RATE_OPTION}})
system.registerMultimoduleProtocol("Flysky AFHDS2A RX", 56, {variants={"Multi", "CPPM"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("FlySky", 1, {variants={"Default", "V9X9", "V6X6", "V912", "CX20"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("FQ777", 23, {options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("FrSky D8", 3, {options={RF_TUNE_OPTION}, minChannels=8, maxChannels=8})
system.registerMultimoduleProtocol("FrskyL", 67, {variants={"LR12", "LR12 6CH"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("FrskyX", 15, {variants={"CH_16", "CH_8", "EU_16", "EU_8", "Cloned", "Cloned_8"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("FrskyX2", 64, {variants={"CH_16", "CH_8", "EU_16", "EU_8", "Cloned", "Cloned_8"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("Frsky_RX", 55, {variants={"Multi", "CloneTX", "EraseTX", "CPPM"}})
system.registerMultimoduleProtocol("FrSky V", 25, {options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("Futaba/SFHSS", 21, {variants={"SFHSS"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("FX", 28, {variants={"816", "620"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("FY326", 20, {variants={"FY326", "FY319"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("GD00X", 47, {variants={"GD_V1*", "GD_V2*"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("Graupner HoTT", 57, {variants={"Sync", "No_Sync"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("GW008", 32, {options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("H8_3D", 36, {variants={"H8_3D", "H20H", "H20Mini", "H30Mini"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("Height", 53, {variants={"5ch", "8ch"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("Hisky", 4, {variants={"Hisky", "HK310"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("Hitec", 39, {variants={"OPT_FW", "OPT_HUB", "MINIMA"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("Hontai", 26, {variants={"HONTAI", "JJRCX1", "X5C1", "FQ777_951"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("Hubsan", 2, {variants={"H107", "H301", "H501"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("J6Pro", 22, {options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("JJRC345", 71, {variants={"JJRC345", "SkyTmblr"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("JOYSWAY", 84, {options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("KF606", 49, {variants={"KF606", "MIG320"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("KN", 9, {variants={"WLTOYS", "FEILUN"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("Kyosho", 73, {variants={"FHSS", "Hype"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("Kyosho2", 93, {variants={"KT-17"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("LOLI", 82, {options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("Losi", 89, {options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("MJXq", 18, {variants={"WLH08", "X600", "X800", "H26D", "E010*", "H26WH", "PHOENIX*"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("MouldKg", 90, {variants={"Analog", "Digit"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("MPX MLINK", 78, {options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("MT99xx", 17, {variants={"MT", "H7", "YZ", "LS", "FY805", "A180", "DRAGON", "F949G"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("MT99xx2", 92, {variants={"PA18"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("NCC1701", 44, {options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("OMP", 77, {features=TELEMETRY, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("OpenLRS", 27, {options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("Pelikan", 60, {variants={"Pro", "Lite", "SCX24"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("Potensic", 51, {variants={"A20"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("PROPEL", 66, {variants={"74-Z"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("Q2X2", 29, {variants={"Q222", "Q242", "Q282"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("Q303", 31, {variants={"Q303", "CX35", "CX10D", "CX10WD"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("Q90C", 72, {variants={"Q90C*"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("RadioLink", 74, {variants={"Surface", "Air", "DumboRC"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("Realacc", 76, {variants={"R11"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("Redpine", 50, {variants={"FAST", "SLOW"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("Scanner", 54, {options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("Shenqi", 19, {variants={"Shenqi"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("Skyartec", 68, {options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("SLT", 11, {variants={"SLT_V1", "SLT_V2", "Q100", "Q200", "MR100"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("Spektrum DSM", 6, {variants={"DSM2-1F", "DSM2-2F", "DSMX-1F", "DSMX-2F", "AUTO", "DSMR-1F"}, minChannels=3, maxChannels=12, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("SymaX", 10, {variants={"SYMAX", "SYMAX5C"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("Tiger", 61, {options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("Traxxas", 43, {variants={"6519 RX"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("V2x2", 5, {variants={"V2x2", "JXD506", "MR101"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("V761", 48, {variants={"3CH", "4CH"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("V911S", 46, {variants={"V911S*", "E119*"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("WFLY", 40, {variants={"WFR0x"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("WFLY2", 79, {variants={"RF20x"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("WK2x01", 30, {variants={"WK2801", "WK2401", "W6_5_1", "W6_6_1", "W6_HEL", "W6_HEL_I"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("XERALL", 91, {variants={"Tank"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("XK", 62, {variants={"X450", "X420"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("YD717", 8, {variants={"YD717", "SKYWLKR", "SYMAX4", "XINXUN", "NIHUI"}, options={RF_TUNE_OPTION}})
system.registerMultimoduleProtocol("ZSX", 52, {variants={"280"}, options={RF_TUNE_OPTION}})
end

return {init=init}